.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

=============
plone.gallery
=============

A photo gallery view for Plone CMS.

Features
--------


Shows photos of different sizes nicely and allows to zoom and browse thru the photos. It uses the libraries `spotlight <https://github.com/nextapps-de/spotlight>`_ and `flexbin <https://github.com/guoyunhe/flexbin>`_ in combination for that.




Translations
------------

This product has been translated into

- German (MrTango)


Installation
------------

Install plone.gallery by adding it to your buildout::

    [buildout]

    ...

    eggs =
        plone.gallery


and then running ``bin/buildout``

TODO
----

- add some more tests for the view


Contribute
----------

- Issue Tracker: https://github.com/plone/plone.gallery/issues
- Source Code: https://github.com/plone/plone.gallery


License
-------

The project is licensed under the GPLv2.
